import os
import sys

import click
import daemonize

from catfish import __version__, worker


@click.group()
@click.version_option(__version__, prog_name="catfish")
def cli():
    pass


@cli.command()
@click.option("--no-fork", is_flag=True)
@click.pass_context
def start(ctx, no_fork):
    if worker.is_running():
        ctx.fail("Worker already running")

    if no_fork:
        worker.run()
    else:
        daemon = daemonize.Daemonize(
            "catfish", worker.PID_FILE, worker.run, foreground=no_fork
        )
        try:
            # HACK: Temporary hack until https://github.com/thesharp/daemonize/pull/70 is solved
            os._exit = sys.exit
            daemon.start()
        except SystemExit:
            worker.wait_for_worker()
        proc = worker.get_running_process()
        click.echo("Worker started with pid {}".format(proc.pid))


@cli.command()
@click.pass_context
def stop(ctx):
    if not worker.is_running():
        ctx.fail("Worker not running")
    proc = worker.get_running_process()
    click.echo("Terminating process {}".format(proc.pid))
    worker.stop_worker()


if __name__ == "__main__":
    cli()
